@@ -6,11 +6,12 @@ Tools for analyzing UEFI firmware and checking UEFI modules with FwHunt rules
 
 __author__ = "FwHunt team"
 __email__ = "fwhunt@binarly.io"
-__version__ = "2.1.1"
+__version__ = "2.2.0"
 
 from .uefi_analyzer import UefiAnalyzer, UefiAnalyzerError
 from .uefi_scanner import UefiRule, UefiScanner, UefiScannerError
 from .uefi_te import TerseExecutableParser
+from .uefi_extractor import UefiBinary, UefiExtractor
 
 __all__ = [
     "UefiAnalyzer",
@@ -19,4 +20,6 @@ __all__ = [
     "UefiScannerError",
     "TerseExecutableParser",
     "UefiAnalyzerError",
+    "UefiBinary",
+    "UefiExtractor",
 ]
